@@ -2,14 +2,6 @@ cv.fishnet <-
   function (outlist, lambda, x, y, weights, offset, foldid, type.measure,
             grouped, keep = FALSE)
 {
-  typenames = c(mse = "Mean-Squared Error", mae = "Mean Absolute Error",
-    deviance = "Poisson Deviance")
-  if (type.measure == "default")
-    type.measure = "deviance"
-  if (!match(type.measure, c("mse", "mae", "deviance"), FALSE)) {
-    warning("Only 'deviance', 'mse' or 'mae'  available for Poisson models; 'deviance' used")
-    type.measure = "deviance"
-  }
   if (!is.null(offset)) {
     is.offset = TRUE
     offset = drop(offset)
@@ -39,8 +31,11 @@ cv.fishnet <-
     nlams[i] = nlami
   }
   N = length(y) - apply(is.na(predmat), 2, sum)
-  cvraw = switch(type.measure, mse = (y - exp(predmat))^2,
-    mae = abs(y - exp(predmat)), deviance = devi(y, predmat))
+  cvraw = switch(type.measure,
+                 mse = (y - exp(predmat))^2,
+                 mae = abs(y - exp(predmat)),
+                 deviance = devi(y, predmat)
+                 )
   if ((length(y)/nfolds < 3) && grouped) {
     warning("Option grouped=FALSE enforced in cv.glmnet, since < 3 observations per fold",
             call. = FALSE)
@@ -55,7 +50,7 @@ cv.fishnet <-
   cvm = apply(cvraw, 2, weighted.mean, w = weights, na.rm = TRUE)
   cvsd = sqrt(apply(scale(cvraw, cvm, FALSE)^2, 2, weighted.mean,
     w = weights, na.rm = TRUE)/(N - 1))
-  out = list(cvm = cvm, cvsd = cvsd, name = typenames[type.measure])
+  out = list(cvm = cvm, cvsd = cvsd, type.measure=type.measure)
   if (keep)
     out$fit.preval = predmat
   out
