@@ -22,6 +22,8 @@ cv.glmnet <-
   glmnet.object = glmnet(x, y, weights = weights, offset = offset,
     lambda = lambda, ...)
   glmnet.object$call = glmnet.call
+  subclass=class(glmnet.object)[[1]]
+  type.measure=cvtype(type.measure,subclass)
   is.offset = glmnet.object$offset
 ###Next line is commented out so each call generates its own lambda sequence
 # lambda=glmnet.object$lambda
@@ -69,7 +71,7 @@ cv.glmnet <-
                weights = weights[!which], ...)
     }
   }
-  fun = paste("cv", class(glmnet.object)[[1]], sep = ".")
+  fun = paste("cv", subclass, sep = ".")
   lambda = glmnet.object$lambda
   cvstuff = do.call(fun, list(outlist, lambda, x, y, weights,
     offset, foldid, type.measure, grouped, keep))
@@ -82,7 +84,8 @@ cv.glmnet <-
     cvsd=cvsd[!nas]
     nz=nz[!nas]
   }
-  cvname = cvstuff$name
+  cvname = names(cvstuff$type.measure)
+  names(cvname)=cvstuff$type.measure# to be compatible with earlier version; silly, I know
   out = list(lambda = lambda, cvm = cvm, cvsd = cvsd, cvup = cvm +
     cvsd, cvlo = cvm - cvsd, nzero = nz, name = cvname, glmnet.fit = glmnet.object)
   if (keep)
